==> cobs-0.8.tgz: cobs-0.8/gb/sb.php <==
<meta http-equiv="Content-Type" CONTENT="text/html; charset=GB2312">
<?php
require("config.php");
require("dbconfig.php");
require("subref.php");
require("lang.php");
$MD[0]="<font size=\"2\">";
/*****************************************
$RD=0 only 
$RD=1  and 
$RD=2 only 
*****************************************/
/**** bible.fhl.net ******/
$MD[1]="<BODY bgcolor=\"#0000c0\" TEXT=\"#eeeeee\" LINK=\"#ffff44\" VLINK=\"#ffff44\" ALINK=\"#ffff44\" ><font size=\"2\">";
/****** a2z.fhl.net *******/
$MD[2]="<BODY bgcolor=\"#aa0000\" TEXT=\"#ffff44\" LINK=\"#eeeeee\" VLINK=\"#eeeeee\" ALINK=\"#eeeeee\" ><font size=\"1\">";
/****** http://www.biblesociety-tw.org/ *******/
$MD[3]="<BODY bgcolor=\"#808040\" TEXT=\"#ffffff\" LINK=\"#eeeeee\" VLINK=\"#eeeeee\" ALINK=\"#eeeeee\" ><font size=\"2\">";
if (($MODE>3)||($MODE<0)) $MODE=0;
if (($DM<1)||($DM>12)) $DM=date("m");
if (($DD<1)||($DD>31)) $DD=date("d");
//echo "$DM $DD ";
$QUERY="select txt,txt1 from daily where sm=$DM and sd=$DD ";
$db_conn=db_connect("host=localhost dbname=$DBNAME");
$result=db_exec($db_conn,$QUERY);
if (!$result){
                        echo "Ͽѯ $QUERY !";
                        exit;
 }
 $numrow=db_NumRows($result);
 if ($numrow!=1)
 {
                        echo "ϱ $numrow 󣡲ѯ $QUERY !";
                        exit;
 }
 $ARAW=db_fetch_row($result,0); //ȡһʼ¼
 if (strlen($ARAW[0])==0)
 {
               echo "$DM  $DD յδ !";
		exit;
 }
 echo "$MD[$MODE] ";
 $ARAW[1]=trim($ARAW[1]);
 $pret=0;
 if ((strlen($ARAW[1])>0)&&($RD>0))
 {
     $spec=ref($ARAW[1],"",0,$db_conn,0);
     echo "ն";
     echogb("$spec<br>");
 	$pret=1;
 }
 if ($RD<2)
 {
   $spec=ref($ARAW[0],"",0,$db_conn,1);
   if ($pret) 
	{	echo "վ䣺";
	      echogb("$spec");
	}
   else echogb("$spec");
 }
?>

==> cobs-0.9.tgz: cobs-0.9/gb/sb.php <==
<meta http-equiv="Content-Type" CONTENT="text/html; charset=GB2312">
<?php
require("config.php");
require("dbconfig.php");
require("subref.php");
require("lang.php");
$MD[0]="<font size=\"2\">";
/*****************************************
$RD=0 only 
$RD=1  and 
$RD=2 only 
*****************************************/
/**** bible.fhl.net ******/
//$MD[1]="<BODY bgcolor=\"#0000c0\" TEXT=\"#eeeeee\" LINK=\"#ffff44\" VLINK=\"#ffff44\" ALINK=\"#ffff44\" ><font size=\"2\">";
$MD[1]="<BODY bgcolor=\"#707070\" TEXT=\"#ffffff\" LINK=\"#ffff44\" VLINK=\"#ffff44\" ALINK=\"#ffff44\" ><font size=\"2\">";
/****** a2z.fhl.net *******/
$MD[2]="<BODY bgcolor=\"#aa0000\" TEXT=\"#ffff44\" LINK=\"#eeeeee\" VLINK=\"#eeeeee\" ALINK=\"#eeeeee\" ><font size=\"1\">";
/****** http://www.biblesociety-tw.org/ *******/
$MD[3]="<BODY bgcolor=\"#808040\" TEXT=\"#ffffff\" LINK=\"#eeeeee\" VLINK=\"#eeeeee\" ALINK=\"#eeeeee\" ><font size=\"2\">";
if (($MODE>3)||($MODE<0)) $MODE=0;
if (($DM<1)||($DM>12)) $DM=date("m");
if (($DD<1)||($DD>31)) $DD=date("d");
//echo "$DM $DD ";
$QUERY="select txt,txt1 from daily where sm=$DM and sd=$DD ";
$db_conn=db_connect("host=localhost dbname=$DBNAME");
$result=db_exec($db_conn,$QUERY);
if (!$result){
                        echo "Ͽѯ $QUERY !";
                        exit;
 }
 $numrow=db_NumRows($result);
 if ($numrow!=1)
 {
                        echo "ϱ $numrow 󣡲ѯ $QUERY !";
                        exit;
 }
 $ARAW=db_fetch_row($result,0); //ȡһʼ¼
 if (strlen($ARAW[0])==0)
 {
               echo "$DM  $DD յδ !";
		exit;
 }
 echo "$MD[$MODE] ";
 $ARAW[1]=trim($ARAW[1]);
 $pret=0;
 if ((strlen($ARAW[1])>0)&&($RD>0))
 {
     $spec=ref($ARAW[1],"",0,$db_conn,0);
     echo "ն";
     echogb("$spec<br>");
 	$pret=1;
 }
 if ($RD<2)
 {
   $spec=ref($ARAW[0],"",0,$db_conn,1);
   if ($pret) 
	{	echo "վ䣺";
	      echogb("$spec");
	}
   else echogb("$spec");
 }
?>
